pub struct SupportCatalogIdentity {
pub schema_version: u32,
pub catalog_version: u32,
pub digest: String,
}Expand description
Shared identity emitted by the Markdown and Pages projections.
Fields
schema_version: u32Fixed complete-support schema version.
catalog_version: u32Documentation catalog version.
digest: StringDigest binding the catalog rows and live registry identity.